#!/bin/bash
# Pull latest openwrt-zipit git and build it

pullchk () {
	# Check is we need to git pull
	# http://stackoverflow.com/questions/3258243/check-if-pull-needed-in-git

	LOCAL=$(git rev-parse @)
	REMOTE=$(git rev-parse @{u})
	BASE=$(git merge-base @ @{u})

	if [ $LOCAL = $REMOTE ]; then
		# Up-to-date
		return 0
	elif [ $LOCAL = $BASE ]; then
		# Need to pull
		return 1
	elif [ $REMOTE = $BASE ]; then
		# Need to push
		return 3
	else
		# Diverged
		return 4
	fi
}

ROOTDIR="/home/mozzwald/openwrt-nightly/"
OPENWRTDIR="openwrt-zipit"
PKGDIR1="openwrt-zipit-packages"
PKGDIR2="openwrt-packages"
BUILD_REQ=0

# Pull latest git if needed
cd "$ROOTDIR$PKGDIR1"
if [ "pullchk" == 1 ]; then
	echo "Syncing openwrt-zipit-packages with github"
	git pull
	BUILD_REQ=1
fi

cd "$ROOTDIR$PKGDIR2"
if [ "pullchk" == 1 ]; then
	echo "Syncing openwrt-packages with github"
	git pull
	BUILD_REQ=1
fi

cd "$ROOTDIR$OPENWRTDIR"
if [ "pullchk" == 1 ]; then
	echo "Syncing openwrt tree with github"
	git pull
	BUILD_REQ=1
fi

if [ $BUILD_REQ -eq 0 ]; then
	echo "No need to run openwrt-nightly build"
#	exit 0
fi

# Move to openwrt dir
cd "$ROOTDIR$OPENWRTDIR"

# Update package list
make package/symlinks V=99
scripts/feeds update -a
scripts/feeds install -a
make defconfig

# Clean the bin dir
#rm -rf "$ROOTDIR$OPENWRTDIR/bin/pxa/*"

# Create pxa bin if needed
mkdir -p "$ROOTDIR$OPENWRTDIR/bin/pxa/"
touch "$ROOTDIR$OPENWRTDIR/bin/pxa/build.log"

# Build
echo ""
echo "Building openwrt-zipit... use 'tail -f $ROOTDIR$OPENWRTDIR/bin/pxa/build.log' for status"
make IGNORE_ERRORS=1 V=99 >> "$ROOTDIR$OPENWRTDIR/bin/pxa/build.log" 2>&1

# check for error
if [ $? -ne 0 ]; then
	echo "FAIL!" >> "$ROOTDIR$OPENWRTDIR/bin/pxa/build.log"
else
	echo "SUCCESS!" >> "$ROOTDIR$OPENWRTDIR/bin/pxa/build.log"
#	echo "`curl --silent http://192.168.1.1/upd-owrt.php -o -`" >> "$ROOTDIR$OPENWRTDIR/bin/pxa/build.log"
fi
